@@ -2,14 +2,16 @@ import logging
 
 from lizard_map.animation import AnimationSettings
 from lizard_map.coordinates import MapSettings
-from lizard_map.daterange import DateRangeForm
-from lizard_map.daterange import current_start_end_dates
 from lizard_map.daterange import current_period
+from lizard_map.daterange import current_start_end_dates
+from lizard_map.daterange import DateRangeForm
+from lizard_map.models import Setting
 from lizard_map.utility import analyze_http_user_agent
-from lizard_map.views import MAP_LOCATION
 from lizard_map.views import MAP_BASE_LAYER
+from lizard_map.views import MAP_LOCATION
 from lizard_map.workspace import WorkspaceManager
 
+
 logger = logging.getLogger(__name__)
 
 
@@ -90,6 +92,8 @@ def workspace_variables(request):
 
     add_to_context['use_workspaces'] = True
 
+    add_to_context['transparency_slider'] = True
+
     return add_to_context
 
 
